@@ -155,7 +155,7 @@ CoinCopyOfArray( const T * array, const int size)
 {
     if (array) {
 	T * arrayNew = new T[size];
-	memcpy(arrayNew,array,size*sizeof(T));
+	std::memcpy(arrayNew,array,size*sizeof(T));
 	return arrayNew;
     } else {
 	return NULL;
@@ -170,10 +170,10 @@ CoinCopyOfArray( const T * array, const int size)
 template <class T> inline T*
 CoinCopyOfArrayPartial( const T * array, const int size,const int copySize)
 {
-    if (array) {
+    if (array||size) {
 	T * arrayNew = new T[size];
 	assert (copySize<=size);
-	memcpy(arrayNew,array,copySize*sizeof(T));
+	std::memcpy(arrayNew,array,copySize*sizeof(T));
 	return arrayNew;
     } else {
 	return NULL;
@@ -189,7 +189,7 @@ CoinCopyOfArray( const T * array, const int size, T value)
 {
     T * arrayNew = new T[size];
     if (array) {
-	memcpy(arrayNew,array,size*sizeof(T));
+        std::memcpy(arrayNew,array,size*sizeof(T));
     } else {
 	int i;
 	for (i=0;i<size;i++) 
@@ -208,9 +208,9 @@ CoinCopyOfArrayOrZero( const T * array , const int size)
 {
     T * arrayNew = new T[size];
     if (array) {
-	memcpy(arrayNew,array,size*sizeof(T));
+      std::memcpy(arrayNew,array,size*sizeof(T));
     } else {
-	memset(arrayNew,0,size*sizeof(T));
+      std::memset(arrayNew,0,size*sizeof(T));
     }
     return arrayNew;
 }
@@ -225,6 +225,7 @@ CoinCopyOfArrayOrZero( const T * array , const int size)
 
     Note JJF - the speed claim seems to be false on IA32 so I have added 
     alternative coding if USE_MEMCPY defined*/
+#ifndef COIN_USE_RESTRICT
 template <class T> inline void
 CoinMemcpyN(register const T* from, const int size, register T* to)
 {
@@ -246,7 +247,7 @@ CoinMemcpyN(register const T* from, const int size, register T* to)
 	throw CoinError("overlapping arrays", "CoinMemcpyN", "");
 #endif
 #endif
-    memcpy(to,from,size*sizeof(T));
+    std::memcpy(to,from,size*sizeof(T));
 #else
     if (size == 0 || from == to)
 	return;
@@ -289,6 +290,16 @@ CoinMemcpyN(register const T* from, const int size, register T* to)
     CoinCopyN(from, size, to);
 #endif
 }
+#else
+template <class T> inline void
+CoinMemcpyN(const T * COIN_RESTRICT from, int size, T* COIN_RESTRICT to)
+{
+  T * put = (T *) to;
+  const T * get = (const T *) from;
+  for ( ; 0<size ; --size)
+    *put++ = *get++;
+}
+#endif
 
 //-----------------------------------------------------------------------------
 
@@ -477,6 +488,21 @@ CoinZero(register T* first, register T* last)
 
 //#############################################################################
 
+/** Returns strdup or NULL if original NULL */
+inline char * CoinStrdup(const char * name)
+{
+  char* dup = NULL;
+  if (name) {
+    const int len = strlen(name);
+    dup = (char*)malloc(len+1);
+    CoinMemcpyN(name, len, dup);
+    dup[len] = 0;
+  }
+  return dup;
+}
+
+//#############################################################################
+
 /** Return the larger (according to <code>operator<()</code> of the arguments.
     This function was introduced because for some reason compiler tend to
     handle the <code>max()</code> function differently. */
